@@ -545,7 +545,6 @@ class fileviewer(object):
         if key_order_se[-1] != '':
             key_order_se.append('')
         
-        
         # laser stuff
         try: 
             val = data.epics.las_pwr
@@ -588,6 +587,18 @@ class fileviewer(object):
         except AttributeError:
             pass
         
+        if key_order_se[-1] != '':
+            key_order_se.append('')
+        
+        # EL3
+        try: 
+            val = data.epics.el3.mean
+            std = data.epics.el3.std
+            data_se['Einzel Lens 3'] = "%.3f +/- %.3f V" % (val, std)
+            key_order_se.append('Einzel Lens 3')
+        except AttributeError:
+            pass
+        
         # NE -----------------------------------------------------------------
         data_ne = {'':''}
         key_order_ne = []
